@@ -3,7 +3,7 @@ use warnings;
 use strict;
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw/json_no_space/;
+our @EXPORT_OK = qw/json_minify/;
 our %EXPORT_TAGS = (
     all => \@EXPORT_OK,
 );
@@ -11,11 +11,11 @@ our %EXPORT_TAGS = (
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.59_01';
+our $VERSION = '0.60_01';
 
 use JSON::Tokenize 'tokenize_json';
 
-sub json_no_space
+sub json_minify
 {
     my ($json) = @_;
     my $tokens = tokenize_json ($json);
